<?php

namespace Packages\Product\Http\Controllers;

use App\Http\Controllers\Controller;
use Facade\Ignition\Support\Packagist\Package;
use Illuminate\Database\Eloquent\Builder;
use Packages\Product\Http\Requests\ProductRequest;
use Packages\Product\Models\Product;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\Upload;
use phpDocumentor\Reflection\Types\Compound;


class ProductController extends Controller
{
    public function __construct()
    {

    }
//  *******************************************show  page product ************
    public function index()
    {
        $categories = Category::orderBy('id', 'DESC')->get();

        $products = Product::query()->orderBy('id', 'DESC');

        if (request()->has('productCategory') && request('productCategory') != '')
            $products = $products->whereHas('categories', function (Builder $query){
                $query->whereRaw('id = ?', [request('productCategory')]);
            });

        if (request()->has('productStatus') && request('productStatus') != '')
            $products = $products->whereRaw('status = ?', [request('productStatus')]);

        if (request()->has('productName') && request('productName') != '')
            $products = $products->whereRaw('title = ?', [request('productName')]);
        if (request()->has('creatorId') && request('creatorId') != '')
            $products = $products->whereHas('user', function (Builder $query) {
                $query->whereRaw('name= ?', [request('creatorId')]);
            });
        $products = $products->paginate();


        return view('product::index', compact('products', 'categories'));

    }

//**************************************************** page create products *****************
    public function create()
    {
        $categories = Category::orderBy('id', 'DESC')->get();

        return view('product::product.create', compact('categories'));
    }

// *********************************************************save products ******************

    public function store(ProductRequest $request)
    {

        $request->merge([
            'price' => preg_replace('/[^0-9]+/', '', $request->price),
            'sale_price' => preg_replace('/[^0-9]+/', '', $request->sale_price),
        ]);
//        $data = array_merge($request->except('categories'), ['creator_id' => auth()->user()->id]);

        $data = [
            'title' => $request->title,
            'slug' => $request->slug,
            'sku' => $request->sku,
            'price' => $request->price,
            'sale_price' => $request->sale_price,
            'type' => $request->type,
            'status' => $request->status,
            'discription' => $request->discription,
            'creator_id' => auth()->user()->id
        ];

        $product = Product::create($data);

       if($request->hasFile('photo')){
            $file = $request-> file('photo');
            $fileName = 'product-file-' . time() . '.' . $file->getClientOriginalName();
           $upload = $file->storeAs('photos' , $fileName , 'product');
           $product= Upload::create([
            'photo' => $upload,
            'path' => 'App\Upload',
            'mime_type' => 'image',



        ]);

        }


        $product->categories()->sync($request->categories);
       $product->upload()->sync($request->upload);
        dd($product);
        $msg = 'ذخیره محصول با موفقیت انجام شد ';
        return redirect(route('products.edit', $product->id),compact('upload'))->with('success', $msg);
    }

    // ******************************************************edit page product*********************************************

    public function edit(Product $product)
    {
        $categories = Category::orderBy('id', 'DESC')->get();
        return view('product::product.edit', compact('product', 'categories'));
    }

// *******************************************update page product*****************************************

    public function update(ProductRequest $request, Product $product)
    {
        $request->merge([
            'price' => preg_replace('/[^0-9]+/', '', $request->price),
            'sale_price' => preg_replace('/[^0-9]+/', '', $request->sale_price),
        ]);

//        $data = array_merge($request->all(), ['creator_id' => auth()->user()->id]);
        $data = [
            'title' => $request->title,
            'slug' => $request->slug,
            'sku' => $request->sku,
            'price' => $request->price,
            'sale_price' => $request->sale_price,
            'type' => $request->type,
            'status' => $request->status,
            'discription' => $request->discription,
            'creator_id' => auth()->user()->id
        ];

        $product->update($data);
        $product->categories()->sync($request->categories);

        $msg = 'ویرایش محصول با موفقیت انجام شد ';

        return redirect(route('products.index'))->with('success', $msg);
    }

    //***************************** delete products*****************************************

    public function destroy(Product $product)
    {

        $product->delete();
        {
            return back();
        }
    }


}
